@@ -1,21 +1,21 @@
-/* $Id: time-out.c 2718 2007-05-06 13:44:42Z jannis $ */
+/* $Id: time-out.c 2892 2007-07-08 14:18:28Z jannis $ */
 /* vim:set et ai sw=2 sts=2: */
 /*-
  * Copyright (c) 2007 Jannis Pohlmann <jannis@xfce.org>
+ * 
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of 
+ * the License, or (at your option) any later version.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * You should have received a copy of the GNU General Public 
+ * License along with this program; if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
  * Boston, MA 02111-1307, USA.
  */
 
@@ -97,8 +97,6 @@ static void           time_out_configure                          (XfcePanelPlug
 static void           time_out_end_configure                      (GtkDialog         *dialog,
                                                                    gint               response_id,
                                                                    TimeOutPlugin     *time_out);
-static void           time_out_break_countdown_seconds_changed    (GtkSpinButton     *spin_button,
-                                                                   TimeOutPlugin     *time_out);
 static void           time_out_lock_countdown_seconds_changed     (GtkSpinButton     *spin_button,
                                                                    TimeOutPlugin     *time_out);
 static void           time_out_postpone_countdown_seconds_changed (GtkSpinButton     *spin_button,
@@ -273,6 +271,10 @@ time_out_construct (XfcePanelPlugin *plugin)
 
   /* Display the about menu item */
   xfce_panel_plugin_menu_show_about (plugin);
+
+  /* Start break countdown if the plugin is active */
+  if (G_LIKELY (time_out->enabled)) 
+    time_out_start_break_countdown (time_out, time_out->break_countdown_seconds);
 }
 
 
@@ -313,6 +315,9 @@ time_out_enabled_toggled (GtkCheckMenuItem *menu_item,
       /* Pause break countdown */
       time_out_countdown_pause (time_out->break_countdown);
     }
+
+  /* Save plugin configuration */
+  time_out_save_settings (time_out);
 }
 
 
@@ -423,10 +428,12 @@ time_out_configure (XfcePanelPlugin *plugin,
   /* Create break countdown time spin */
   spin = gtk_spin_button_new_with_range (1, 24 * 60, 1);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), time_out->break_countdown_seconds / 60);
-  g_signal_connect (spin, "value-changed", G_CALLBACK (time_out_break_countdown_seconds_changed), time_out);
   gtk_table_attach_defaults (GTK_TABLE (table), spin, 1, 2, 0, 1);
   gtk_widget_show (spin);
 
+  /* Store reference on the spin button in the plugin */
+  g_object_set_data (G_OBJECT (time_out->plugin), "break-countdown-seconds-spin", spin);
+
   /* Create lock countdown time label */
   label = gtk_label_new (_("Break length (minutes):"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
@@ -509,18 +516,38 @@ time_out_end_configure (GtkDialog     *dialog,
                         gint           response_id,
                         TimeOutPlugin *time_out)
 {
+  GtkWidget *spin;
+  gint       value;
+  gboolean   restart = FALSE;
+
   /* Remove the dialog data from the plugin */
   g_object_set_data (G_OBJECT (time_out->plugin), "dialog", NULL);
 
   /* Unlock the panel menu */
   xfce_panel_plugin_unblock_menu (time_out->plugin);
 
+  /* Get spin button value for the break countdown settings */
+  spin = g_object_get_data (G_OBJECT (time_out->plugin), "break-countdown-seconds-spin");
+  value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin)) * 60;
+  g_object_set_data (G_OBJECT (time_out->plugin), "break-countdown-seconds-spin", NULL);
+
+  /* Check if the break countdown seconds have changed */
+  restart = value != time_out->break_countdown_seconds;
+
+  /* Apply new break countdown seconds */
+  time_out->break_countdown_seconds = value;
+
   /* Save plugin configuration */
   time_out_save_settings (time_out);
 
-  /* Restart break countdown */
-  time_out_stop_break_countdown (time_out);
-  time_out_start_break_countdown (time_out, time_out->break_countdown_seconds);
+  /* Restart or resume break countdown */
+  if (G_UNLIKELY (restart && time_out->enabled))
+    {
+      time_out_stop_break_countdown (time_out);
+      time_out_start_break_countdown (time_out, time_out->break_countdown_seconds);
+    }
+  else
+    time_out_countdown_resume (time_out->break_countdown);
 
   /* Destroy the properties dialog */
   gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -528,19 +555,6 @@ time_out_end_configure (GtkDialog     *dialog,
 
 
 
-static void
-time_out_break_countdown_seconds_changed (GtkSpinButton *spin_button,
-                                          TimeOutPlugin *time_out)
-{
-  g_return_if_fail (GTK_IS_SPIN_BUTTON (spin_button));
-  g_return_if_fail (time_out != NULL);
-
-  /* Set plugin attribute */
-  time_out->break_countdown_seconds = gtk_spin_button_get_value_as_int (spin_button) * 60;
-}
-
-
-
 static void
 time_out_lock_countdown_seconds_changed (GtkSpinButton *spin_button,
                                          TimeOutPlugin *time_out)
@@ -701,7 +715,7 @@ time_out_save_settings (TimeOutPlugin *time_out)
   if (G_LIKELY (filename != NULL))
     {
       /* Open file handle */
-      rc = xfce_rc_simple_open (filename, TRUE);
+      rc = xfce_rc_simple_open (filename, FALSE);
 
       /* Check if the file could be opened */
       if (G_LIKELY (rc != NULL))
@@ -854,6 +868,8 @@ time_out_lock_countdown_update (TimeOutCountdown *countdown,
   g_return_if_fail (time_out != NULL);
 
   /* Update lock screen */
+  time_out_lock_screen_set_display_seconds (time_out->lock_screen, time_out->display_seconds);
+  time_out_lock_screen_set_display_hours (time_out->lock_screen, time_out->display_hours);
   time_out_lock_screen_set_remaining (time_out->lock_screen, seconds_remaining);
 }
 
